==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeExtensionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeExtensionArgs.builder
import com.pulumi.azurenative.providerhub.kotlin.enums.ExtensionCategory
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property endpointUri
 * @property extensionCategories
 * @property timeout
 */
public data class ResourceTypeExtensionArgs(
    public val endpointUri: Output<String>? = null,
    public val extensionCategories: Output<List<Either<String, ExtensionCategory>>>? = null,
    public val timeout: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeExtensionArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.inputs.ResourceTypeExtensionArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeExtensionArgs.builder()
            .endpointUri(endpointUri?.applyValue({ args0 -> args0 }))
            .extensionCategories(
                extensionCategories?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .timeout(timeout?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceTypeExtensionArgs].
 */
@PulumiTagMarker
public class ResourceTypeExtensionArgsBuilder internal constructor() {
    private var endpointUri: Output<String>? = null

    private var extensionCategories: Output<List<Either<String, ExtensionCategory>>>? = null

    private var timeout: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("icgednnkhbwfxgfs")
    public suspend fun endpointUri(`value`: Output<String>) {
        this.endpointUri = value
    }

    /**
     * @param value
     */
    @JvmName("ygyjxlvmdfuakowk")
    public suspend fun extensionCategories(`value`: Output<List<Either<String, ExtensionCategory>>>) {
        this.extensionCategories = value
    }

    @JvmName("fmolgdmsirmbujen")
    public suspend fun extensionCategories(vararg values: Output<Either<String, ExtensionCategory>>) {
        this.extensionCategories = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("kgvdcakdekfjsini")
    public suspend fun extensionCategories(values: List<Output<Either<String, ExtensionCategory>>>) {
        this.extensionCategories = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("egkumwmpakodingg")
    public suspend fun timeout(`value`: Output<String>) {
        this.timeout = value
    }

    /**
     * @param value
     */
    @JvmName("bvvpxpscudgovmeo")
    public suspend fun endpointUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endpointUri = mapped
    }

    /**
     * @param value
     */
    @JvmName("wxqydiyvoyfjyekb")
    public suspend fun extensionCategories(`value`: List<Either<String, ExtensionCategory>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extensionCategories = mapped
    }

    /**
     * @param values
     */
    @JvmName("mwfsfaujuuenamfr")
    public suspend fun extensionCategories(vararg values: Either<String, ExtensionCategory>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.extensionCategories = mapped
    }

    /**
     * @param value
     */
    @JvmName("jpyhqrplqwixgxra")
    public suspend fun timeout(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeout = mapped
    }

    internal fun build(): ResourceTypeExtensionArgs = ResourceTypeExtensionArgs(
        endpointUri = endpointUri,
        extensionCategories = extensionCategories,
        timeout = timeout,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeExtensionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeExtensionArgs.builder
import com.pulumi.azurenative.providerhub.kotlin.enums.ExtensionCategory
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property endpointUri
 * @property extensionCategories
 * @property timeout
 */
public data class ResourceTypeExtensionArgs(
    public val endpointUri: Output<String>? = null,
    public val extensionCategories: Output<List<Either<String, ExtensionCategory>>>? = null,
    public val timeout: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeExtensionArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.inputs.ResourceTypeExtensionArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeExtensionArgs.builder()
            .endpointUri(endpointUri?.applyValue({ args0 -> args0 }))
            .extensionCategories(
                extensionCategories?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .timeout(timeout?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceTypeExtensionArgs].
 */
@PulumiTagMarker
public class ResourceTypeExtensionArgsBuilder internal constructor() {
    private var endpointUri: Output<String>? = null

    private var extensionCategories: Output<List<Either<String, ExtensionCategory>>>? = null

    private var timeout: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("auflscbeutanlgev")
    public suspend fun endpointUri(`value`: Output<String>) {
        this.endpointUri = value
    }

    /**
     * @param value
     */
    @JvmName("yopxsrlbymdhrsgh")
    public suspend fun extensionCategories(`value`: Output<List<Either<String, ExtensionCategory>>>) {
        this.extensionCategories = value
    }

    @JvmName("inysftpcvmvfbath")
    public suspend fun extensionCategories(vararg values: Output<Either<String, ExtensionCategory>>) {
        this.extensionCategories = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("iuomqxkglrpqtfty")
    public suspend fun extensionCategories(values: List<Output<Either<String, ExtensionCategory>>>) {
        this.extensionCategories = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("kjijhvfqvdxbvier")
    public suspend fun timeout(`value`: Output<String>) {
        this.timeout = value
    }

    /**
     * @param value
     */
    @JvmName("ynftisnktffrkeig")
    public suspend fun endpointUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endpointUri = mapped
    }

    /**
     * @param value
     */
    @JvmName("wepudidqilgubpqp")
    public suspend fun extensionCategories(`value`: List<Either<String, ExtensionCategory>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extensionCategories = mapped
    }

    /**
     * @param values
     */
    @JvmName("bymjhqtmnlsosgob")
    public suspend fun extensionCategories(vararg values: Either<String, ExtensionCategory>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.extensionCategories = mapped
    }

    /**
     * @param value
     */
    @JvmName("bxstshddxguusdtd")
    public suspend fun timeout(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeout = mapped
    }

    internal fun build(): ResourceTypeExtensionArgs = ResourceTypeExtensionArgs(
        endpointUri = endpointUri,
        extensionCategories = extensionCategories,
        timeout = timeout,
    )
}
